@@ -132,10 +132,14 @@ class EnsemblingSignalRunner(AbstractRunner):
                 hourlyperf_df = self.precomputed_results_df[me_signal]
                 hourlysig_df = self.precomputed_signals_df[me_signal]
                 hourlyperf_df = hourlyperf_df.to_frame()
-                hourlyperf_df.columns = ['close']
+                hourlyperf_df.columns = ['reconstituted_perf']
                 hourlysig_df = hourlysig_df.to_frame()
                 hourlysig_df.columns = ['signal']
                 hourly_df = hourlyperf_df.merge(hourlysig_df, left_index = True, right_index = True)
+                if cumulated_signals is None :
+                    hourlyclose_df = hourly_df['close'].to_frame()
+                    hourlyclose_df.columns = ['close']
+                    hourly_df = hourly_df.merge(hourlyclose_df, left_index=True, right_index=True)
 
             if cumulated_signals is None:
                 if self.add_turn_over:
